@@ -21,7 +21,7 @@ import logging
 import re
 import threading
 from datetime import datetime
-from typing import Callable, Dict, List, Pattern
+from typing import Any, Callable, Dict, List, Pattern
 
 from .chat_context import ChatContext
 from .job_queue import JobQueue
@@ -67,6 +67,13 @@ class Bot:
         self._handlers.append((regex, func))
         self.log.info(f"Handler <{func.__name__}> registered ('{regex.pattern}')")
 
+    def handler(self, regex: Pattern):
+        """Decorator to register handlers."""
+        def decorator(func: Callable):
+            self.register_handler(regex, func)
+            return func
+        return decorator
+
     def _handle_message(self, message: Message, func: Callable, match) -> None:
         """Handle a matched message."""
         message_id = id(message)
@@ -97,6 +104,9 @@ class Bot:
         """Match an incoming message against a handler."""
         message_id = id(message)
         message_source = message.get_redacted_source()
+
+        # Mark message as delivered.
+        message.mark_delivered()
         self.log.debug(f"Message ({message_id}) received from {message_source}")
         self.log.debug(str(message))
 
